@@ -1,7 +1,7 @@
 package HTML::Make;
 use warnings;
 use strict;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 use Carp;
 use HTML::Valid::Tagset ':all';
 
@@ -103,6 +103,14 @@ sub add_text
     return $x;
 }
 
+sub add_comment
+{
+    my ($obj, $comment) = @_;
+    my $x = __PACKAGE__->new ($texttype, text => "<!-- $comment -->");
+    CORE::push @{$obj->{children}}, $x;
+    return $x;
+}
+
 sub check_mismatched_tags
 {
     my ($obj, $el) = @_;
